<?php

namespace modules\sales\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use modules\crm\Models\BusinessContact;
use modules\location\Models\Location;

class AccountingDocument extends Model
{
    use HasFactory;

    protected $table = "accounting_documents";
    protected $fillable = [
        'location_id',
        'location',
        "document_type",
        "link_to",
        "accounting_document_id",
        "numero",
        "reference",
        "accounting_document_date",
        "accounting_document_release_date",
        "customer_id",
        "customer",
        "customer_email",
        "customer_phone",
        "customer_address",
        "discount_by",
        "discount_rate",
        "discount_price",
        "tva_rate",
        "tva_price",
        "total_ht",
        "total_ttc",
        "slug",
        "validate",
        "user_id",
        "username",
        "edited_by",
        "edited_name",
        "document_for",
        'document_logo',
        'document_header',
        'document_footer',
        'delivery_price',
    ];

    public function customer(){        
        return $this->belongsTo(BusinessContact::class, 'customer_id');
    }

    public function status() {
        return $this->hasMany(AccountingDocStatusLog::class, 'accounting_document_id', 'id')->orderByDesc('created_at');
    }

    public function stories(){
        return $this->hasMany(AccountingDocumentLog::class, 'accounting_document_id', 'id')
                ->select(
                    'accounting_documents_logs.*', 
                    'accounting_documents_status.title as status_name', 
                    'accounting_documents_status.icon as status_icon', 
                    'accounting_documents_status.background as background', 
                    'accounting_documents_status.color as color',
                )
                #->join('accounting_documents_logs', 'accounting_documents_logs.id', '=', 'accounting_documents_logs.accounting_documents_logs_id')
                ->join('accounting_documents_status', 'accounting_documents_status.id', '=', 'accounting_documents_logs.accounting_document_status_id')
                ->orderByDesc('accounting_documents_logs.created_at');
    }

    public function invoice_type()
    {
        return $this->belongsTo(InvoiceType::class, 'id', 'invoice_id');
    }


    /*public function details(){
        return $this->hasMany(AccountingDocumentDetail::class, 'accounting_document_id', 'id');
    }*/

    public function details()
    {
        return $this->hasMany(AccountingDocumentDetail::class, 'accounting_document_id', 'id')
            ->with(['category']);
    }

    public function location(){
        return $this->belongsTo(Location::class, 'location_id');
    }
    
    public function payments(){
        return $this->hasMany(AccountingDocumentPayment::class, 'accounting_document_id', 'id');
    }

}