<?php

use Illuminate\Support\Facades\Route;
use modules\sales\Http\Controllers\AccountingDocumentController;
use modules\sales\Http\Controllers\basketController;
use modules\sales\Http\Controllers\caisseController;
use modules\sales\Http\Controllers\PaymentMethodController;
use modules\sales\Http\Controllers\salesController;
use modules\sales\Http\Controllers\settingsController;

Route::as("app.")->middleware(['auth', 'web'])->group(function(){
    Route::prefix('vente/caisse')->as('receipt.')->group(function(){
        Route::match(['get', 'post'], '/comptoir/caisse/open', [salesController::class, 'openCaisse'])->name('caisse.open');
        Route::get('/comptoir/caisse/status', [salesController::class, 'caisseStatus'])->name('caisse.status');
        
        Route::get('/comptoir', [salesController::class, 'index'])->name('index');                        
    });

    Route::prefix('vente/{type}/document')->as('sales.documents.')->group(function(){
        Route::get('/', [AccountingDocumentController::class, 'index'])->name('index');
        Route::get('/create', [AccountingDocumentController::class, 'create'])->name('create');
        Route::get('/edit/{slug}', [AccountingDocumentController::class, 'edit'])->name('edit');
        Route::get('/get/data', [AccountingDocumentController::class, 'getdata'])->name('get');

        Route::get('/print/document/{slug}', [AccountingDocumentController::class, 'document'])->name('document');

        Route::post('store/info', [AccountingDocumentController::class, 'store_info'])->name('info.store');
        Route::post('status', [AccountingDocumentController::class, 'status'])->name('status');
        Route::post('payment', [AccountingDocumentController::class, 'payment'])->name('payment');
    });
    
    Route::prefix('basket')->as('basket.')->group(function(){
        Route::get('load', [basketController::class, 'load'])->name('load');

        Route::post('store', [basketController::class, 'store'])->name('store');    
        Route::delete('delete/{id}', [basketController::class, 'destroy'])->name('destroy');    
    });    
    
    Route::prefix('setting/vente')->as('sales.setting.')->group(function(){
        Route::get('/', [settingsController::class, 'setting'])->name('index');
        Route::post('/numero', [settingsController::class, 'numero_store'])->name('numerotation.save');
        Route::get('/numero/get', [settingsController::class, 'numero'])->name('numerotation.get');
        
        #caisses
        Route::get('/caisses/get', [caisseController::class, 'caisses'])->name('caisse.get');
        Route::post('/caisses/save', [caisseController::class, 'save'])->name('caisse.save');
        Route::post('/caisses/status', [caisseController::class, 'status'])->name('caisse.status');
        
        Route::delete('/caisses/delete/{id}', [caisseController::class, 'delete'])->name('caisse.delete');
        #caisses
        
        #payment_methods
        Route::get('/payment-methods/get', [PaymentMethodController::class, 'payment_methods'])->name('payment-methods.get');
        #payment_methods
    });
});

